@@ -7,9 +7,6 @@ RcppLdPath <- function() {
     } else {
         path <- system.file("lib",package="Rcpp")
     }
-    if (.Platform$OS.type=="windows") {
-        path <- paste('"', path, '"', sep="")
-    }
     path
 }
 
@@ -24,6 +21,9 @@ RcppLdFlags <- function(static=TRUE) {
     rcppdir <- RcppLdPath()
     if (static) {                               # static is default on Windows and OS X
         flags <- paste(rcppdir, "/libRcpp.a", sep="")
+        if (.Platform$OS.type=="windows") {
+            flags <- paste('"', flags, '"', sep="")
+        }
     } else {					# else for dynamic linking
         flags <- paste("-L", rcppdir, " -lRcpp", sep="") # baseline setting
         if ((.Platform$OS.type == "unix") &&    # on Linux, we can use rpath to encode path
@@ -39,7 +39,11 @@ canUseCXX0X <- function() .Call( "canUseCXX0X", PACKAGE = "Rcpp" )
 
 ## Provide compiler flags -- i.e. -I/path/to/Rcpp.h
 RcppCxxFlags <- function(cxx0x=FALSE) {
-    paste("-I", RcppLdPath(), if( cxx0x && canUseCXX0X() ) " -std=c++0x" else "", sep="")
+    path <- RcppLdPath()
+    if (.Platform$OS.type=="windows") {
+        path <- paste('"', path, '"', sep="")
+    }
+    paste("-I", path, if( cxx0x && canUseCXX0X() ) " -std=c++0x" else "", sep="")
 }
 
 ## Shorter names, and call cat() directly
